@@ -34,15 +34,13 @@ predict.cotram <- function(object, newdata = model.frame(object),
     }
     
     
-    ## linear predictor
+    ## linear predictor (shift / scale possible)
     if (type == "lp") {
-        ret <- model.matrix(object, data = newdata) %*% 
-            coef(object, with_baseline = FALSE)
-        if (object$negative) return(-ret)
-        return(ret)
+        class(object) <- class(object)[-1L]
+        ### use ... to specify "what" in predict.stram
+        return(predict(object, newdata = newdata, type = "lp", ...))
     }
     
-    
     if (smooth) {
         
         ret <- predict(as.mlt(object), newdata = newdata, type = type, q = q,
